<?php

namespace Drupal\authorization_code\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configuration form for authorization_code settings config.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'authorization_code_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['authorization_code.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form = parent::buildForm($form, $form_state);

    $form['seconds_to_expire'] = [
      '#type' => 'number',
      '#title' => $this->t('Seconds to expire'),
      '#default_value' => $this->config('authorization_code.settings')
        ->get('seconds_to_expire'),
      '#min' => '1',
      '#description' => $this->t('The number of seconds each code will remain active.'),
    ];

    $form['max_fetches'] = [
      '#type' => 'number',
      '#title' => $this->t('Max fetches'),
      '#default_value' => $this->config('authorization_code.settings')
        ->get('max_fetches'),
      '#min' => '1',
      '#description' => $this->t('The maximum number of times a code can be fetched and validated against.'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    foreach ($form_state->getValues() as $key => $value) {
      $this->config('authorization_code.settings')->set($key, $value);
    }
    $this->config('authorization_code.settings')->save();
    $this->messenger()
      ->addStatus($this->t('The Authorization Code settings have been saved.'));
  }

}
